function sxt_suture,img,satpix,unc,unc_out=unc_out,$
	noise_factor=noise_factor
;+
; NAME
;	sxt_suture
; PURPOSE
;	  Fill in saturated areas in an SXT image with statistically
;	randomized data interpolated from both sides of the bleed.
;	  For use in sxt_composite.pro but can be used with
;	any sxt image with saturated parts.  NOTE:  This
;	code cannot tell the difference between true solar saturation
;	and saturation due to bleed.
; CALLING SEQUENCE
;	out=sxt_suture(img,satpix,unc,unc_out=unc_out,$
;		noise_factor=noise_factor)
;	out=sxt_suture(img,satpix,unc,noise_factor=3.0
; INPUT
;	img = SXT image produced by SXT_PREP
;	satpix = Boolean image showing saturated pixels
;		(e.g., from SXT_PREP)
; OPTIONAL INPUT
;	unc = uncertainty array from sxt_dn_unc.pro. (Must be 
;		present to add noise to the interpolated data.)
; OPTIONAL KEYWORD INPUT
;	noise_factor = set this to a value such that the visual
;		appearance of the interpolated resembles the
;		statistical appearance of the unsaturated image.
;		A larger number lowers the noise. (default=1.0)
; OPTIONAL KEYWORD OUTPUT
;	unc_out = uncertainty array of the sutured image.  This estimate
;		  includes the added noise and the uncertainties of the
;		  non-saturated pixels on either side of the interpolation,
;		  added in quadrature.
; HISTORY
;	 7-9 Oct 2000  LWA, written and tested.
;	11 Oct 2000  LWA, added unc_out capability & updated header.
;       18-Dec-2000, S.L.Freeland - remove 512x512 restriction
;	11-Jan-2001, DMcK & LWA - The output uncert is now an honest
;			attempt to estimate the uncertainty in the
;			sutured pixels.
;	13-Jan-2001, LWA, Fixed uncert addressing error.
;			Revised uncertainty algorithm.
;-

if NOT keyword_set(noise_factor) then nf=1.0 else nf=noise_factor

dx=data_chk(img,/nx)
dy=data_chk(img,/ny)
out=img					;SET UP VECTORS
unc_out=unc
ss=where(satpix eq 1)
yy=ss/dx
xx=ss mod dx
yu=uniq(yy)

for i=0,n_elements(yu)-1 do begin	;ONE ROW AT A TIME
   row=satpix(*,yy(yu(i)))		;FIND SATURATIONS 
   ii=where(row eq 1)
   jj=ii-shift(ii,1)
   kk=ii-shift(ii,-1)
   jji=where(jj ne 1)
   kki=where(kk ne -1)

   for j=0,n_elements(jji)-1 do begin	;ONE SATURATION AT A TIME
      xlo=ii(jji(j))
      xhi=ii(kki(j))
      fit=poly_fit([xlo-1,xhi+1],$	;INTERPOLATE DATA
        	[img(xlo-1,yy(yu(i))),$
        	img(xhi+1,yy(yu(i)))],1)
      result=fit(0)+(fit(1)*(indgen(xhi-xlo+1)+xlo))
      if n_elements(unc) ne 0 then begin	;ADD NOISE
         sigfit=poly_fit([xlo-1,xhi+1],$
		[unc(xlo-1,yy(yu(i))),$
        	unc(xhi+1,yy(yu(i)))],1)
         sigma=sigfit(0)+(sigfit(1)*(indgen(xhi-xlo+1)+xlo))
	 add_noise=sigma
         for k=0,n_elements(result)-1 do begin
	    add_noise(k)=sigma(k)*randomn(seed)/nf
            result(k)=result(k)+add_noise(k)
            sigma(k)=0.6*(0.25*add_noise(k)+unc(xlo-1,yy(yu(i)))+$
                                        unc(xhi+1,yy(yu(i))))
         endfor		; "Reasonable" uncert estimate, 13-jan-01, LWA
      endif
      out(xlo:xhi,yy(yu(i)))=result		;WRITE TO ARRAYS
      unc_out(xlo:xhi,yy(yu(i)))=sigma
   endfor

endfor

return,out

end
